;; -*-emacs-lisp-*-
;;
;; Emacs startup file for the Debian jde package
;;
;; Originally contributed by Nils Naumann <naumann@unileoben.ac.at>
;; Modified by Dirk Eddelbuettel <edd@debian.org>
;; Adapted for dh-make by Jim Van Zandt <jrv@vanzandt.mv.com>

(if (not (file-exists-p "/usr/share/emacs/site-lisp/jde"))
    (message "Package jde removed but not purged.  Skipping setup.")

  ;; The jde package follows the Debian/GNU Linux 'emacsen' policy and
  ;; byte-compiles its elisp files for each 'emacs flavor' (emacs19,
  ;; xemacs19, emacs20, xemacs20...).  The compiled code is then
  ;; installed in a subdirectory of the respective site-lisp directory.
  ;; We have to add this to the load-path:
  (let ((package-dir (concat "/usr/share/"
                             (symbol-name flavor)
                             "/site-lisp/jde")))
    (when (file-directory-p package-dir)
      (debian-pkg-add-load-path-item package-dir)))

  ;; Set default paths
  (setq bsh-jar "/usr/share/java/bsh.jar")
  (setq jde-jar-file "/usr/share/java/jde.jar")
  (setq jde-checkstyle-jar-file "/usr/share/java/checkstyle.jar")
  (setq jde-regexp-jar-file "/usr/share/tomcat5/server/lib/jakarta-regexp.jar")
  (setq jde-java-directory "/usr/share/java")
  (setq jde-doc-directory "/usr/share/doc/jde")

  ;; Workaround for JDK 1.6
  (require 'beanshell)
  (require 'jde-compile)
  (defclass jde-compile-javac-16 (jde-compile-javac-15)
    ()
    "Class of J2SDK 1.6 javac compilers.")
  (defmethod initialize-instance ((this
                                   jde-compile-javac-16) &rest fields)
    ;; Call parent initializer.
    (call-next-method)

    ;; Set compiler version.
    (oset this version "1.6"))
  (add-to-list 'jde-compile-javac-compilers
               (jde-compile-javac-16 "javac 1.6.x") t)

  ;; Workaround for JDK 1.7
  (defclass jde-compile-javac-17 (jde-compile-javac-16)
    ()
    "Class of J2SDK 1.7 javac compilers.")
  (defmethod initialize-instance ((this
                                   jde-compile-javac-17) &rest fields)
    ;; Call parent initializer.
    (call-next-method)

    ;; Set compiler version.
    (oset this version "1.7"))
  (add-to-list 'jde-compile-javac-compilers
               (jde-compile-javac-17 "javac 1.7.x") t)

  ;; Enable autoloads so that JDEE gets activated when .java files are
  ;; visited.  We do this by loading jde.el instead of loading
  ;; jde-autoloads.el, because otherwise emacs21 and xemacs21 do not
  ;; behave well the first time a .java file is visited.
  (require 'jde)

  ;; Set the global-senator-minor-mode to t to fix broken syntax
  ;; highlighting with semantic Version 1.0beta3b-1 (Bug #267520).
  (setq global-senator-minor-mode t)

  ;; Register all available JDKs on the system
  (defun debian-jde-register-jdks ()
    "Register all available JDKs automatically given the output of
update-java-alternatives."
    (when (file-executable-p "/usr/sbin/update-java-alternatives")
      (with-temp-buffer
        (shell-command "/usr/sbin/update-java-alternatives --list" t)
        (goto-char (point-min))
        (let (jdks)
          (while (and (< (point) (point-max))
                      (looking-at
                       "\\([^ \n]+\\) \\([^ \n]+\\) \\([^ \n]+\\)$"))
            (let ((name (match-string 1))
                  (version (match-string 2))
                  (jdk-path (match-string 3)))
              (when (string-match "\\`[0-9]\\{4\\}\\'" version)
                (setq version (concat
                               (substring version 0 1) "."
                               (number-to-string
                                (string-to-number (substring version 1 3)))
                               "." (substring version 3 4))))
              (add-to-list 'jdks (cons version jdk-path)))
            (forward-line 1))
          (jde-set-jdk-dir-type 'jde-jdk-registry (nreverse jdks))))))
  (debian-jde-register-jdks))
